==> msxpertsuite_5.7.3.orig.tar.gz: msxpertsuite-5.7.3/minexpert/nongui/MassSpecDataFileLoaderXy.hpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2018 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */




#pragma once


////////////////////////////// Qt includes
#include <QStringList>
#include <QRegularExpression>

////////////////////////////// local includes
#include <minexpert/nongui/MassSpecDataFileLoader.hpp>
#include <libmass/MassSpectrum.hpp>
#include <minexpert/nongui/MassSpecDataSet.hpp>


namespace msXpSmineXpert
{

	class MassSpecDataFileLoaderXy : public MassSpecDataFileLoader
	{
		public:

			MassSpecDataFileLoaderXy(const QString &filename = QString());
			~MassSpecDataFileLoaderXy();

			QString formatDescription() const override;
			int readSpectrumCount() override;

			// Data loading
			static bool canLoadData(QString fileName);
			static bool canLoadDataFromString(const QString &msDataString);

			msXpSlibmass::MassSpectrum *loadData();
			int loadDataFromString(const QString &msDataString, MassSpecDataSet *massSpecDataSet);
			int loadData(MassSpecDataSet *massSpecDataSet);
			int loadData(QVector<double> *keyVector,
					QVector<double> *valVector);
			int loadData(QMap<double, double> *keyValMap);
	};


} // namespace msXpSmineXpert

==> msxpertsuite_5.8.6.orig.tar.gz: msxpertsuite-5.8.6/minexpert/nongui/MassSpecDataFileLoaderXy.hpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2018 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */


#pragma once


////////////////////////////// Qt includes
#include <QStringList>
#include <QRegularExpression>

////////////////////////////// local includes
#include <minexpert/nongui/MassSpecDataFileLoader.hpp>
#include <libmass/MassSpectrum.hpp>
#include <minexpert/nongui/MassSpecDataSet.hpp>


namespace msXpSmineXpert
{

class MassSpecDataFileLoaderXy : public MassSpecDataFileLoader
{
  public:
  MassSpecDataFileLoaderXy(const QString &filename = QString());
  ~MassSpecDataFileLoaderXy();

  QString formatDescription() const override;
  int readSpectrumCount() override;

  // Data loading
  static bool canLoadData(QString fileName);
  static bool canLoadDataFromString(const QString &msDataString);

  msXpSlibmass::MassSpectrum *loadData();
  int loadDataFromString(const QString &msDataString,
                         MassSpecDataSet *massSpecDataSet);
  int loadData(MassSpecDataSet *massSpecDataSet);
  int loadData(QVector<double> *keyVector, QVector<double> *valVector);
  int loadData(QMap<double, double> *keyValMap);
};


} // namespace msXpSmineXpert
